# textual-bee

![preview](https://raw.githubusercontent.com/torshepherd/textual-bee/main/preview.png)

Get it on PyPI:

```sh
pip install textual-bee
textual-bee
```

## How to play

Submit words that include the center letter and are at least 4 letters long.

- Press the shuffle button (spacebar) to shuffle the outer letters.
- Press CTRL-C to quit.
- Press CTRL-R to reset and choose a new set of letters.
- Press (tab) to view your already-found words.

## Scoring

Your grade is based on how many of the possible words you find:

| Words found | Grade      |
| ----------- | ---------- |
| 0-2%        | Beginner   |
| 2-5%        | Good Start |
| 5-8%        | Moving Up  |
| 8-15%       | Good       |
| 15-25%      | Solid      |
| 25-40%      | Nice       |
| 40-50%      | Great      |
| 50-70%      | Amazing    |
| 70-100%     | Genius     |
| 100%        | Queen Bee  |

### Notes:

The word list doesn't correspond exactly to Sam's, but it was the closest I could find (margin of error seemed to be about 10%). In general, this game allows more proper nouns and fewer esoteric words, but it varies depending on the setup.

_Inspired by https://github.com/ajeetdsouza/clidle_
